@@ -1,17 +1,16 @@
-/* $Id: test14.c,v 1.5 1999/10/26 08:33:40 amai Exp $
+/* $Id: test14.c,v 1.7 2002/05/01 15:54:45 amai Exp $
    Test 14.c: Test if various things that effect the geometry when sizePolicy 
               is XmRESIZE_IF_POSSIBLE
    Notes: Geometry does not change after widget is realized
 */
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdarg.h>
 
 #include <Xm/BulletinB.h>
 #include <Xm/ListP.h>
 #include <Xm/PushBP.h>
-#include "XdbPrintTree.c"
-#include "XdbPrintResources.c"
+
+#include "../../common/Test.h"
 
 void
 onActivate(Widget w, XtPointer foo1, XtPointer foo2)
